@@ -22,8 +22,8 @@
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA. */
 #include <Foundation/Foundation.h>
 #include <AppKit/AppKit.h>
-#include <AppKit/GSHbox.h>
-#include <AppKit/GSVbox.h>
+#include <GNUstepGUI/GSHbox.h>
+#include <GNUstepGUI/GSVbox.h>
 #include "../GSTestProtocol.h"
 
 @interface EncodingDecodingTest: NSObject <GSTest>
@@ -70,8 +70,6 @@ willDisplayCell: (id)cell
   button = [NSButton new];
   [button setTitle: @"Decode from File..."];
   [button sizeToFit];
-  [button setFrameSize: NSMakeSize ([button frame].size.width + 6, 
-				    [button frame].size.height + 4)];
   [button setAutoresizingMask: NSViewMinXMargin | NSViewMaxXMargin];
   [button setTarget: self];
   [button setAction: @selector (decode:)];
@@ -94,8 +92,6 @@ willDisplayCell: (id)cell
   button = [NSButton new];
   [button setTitle: @"Encode to File..."];
   [button sizeToFit];
-  [button setFrameSize: NSMakeSize ([button frame].size.width + 4, 
-				    [button frame].size.height + 6)];
   [button setAutoresizingMask: NSViewMinXMargin | NSViewMaxXMargin];
   [button setTarget: self];
   [button setAction: @selector (encode:)];
