@@ -23,9 +23,9 @@
 
 #include <Foundation/Foundation.h>
 #include <AppKit/AppKit.h>
-#include <AppKit/GSHbox.h>
-#include <AppKit/GSTable.h>
-#include <AppKit/GSVbox.h>
+#include <GNUstepGUI/GSHbox.h>
+#include <GNUstepGUI/GSTable.h>
+#include <GNUstepGUI/GSVbox.h>
 #include "../GSTestProtocol.h"
 
 #define STYLE_NUMBER 6
@@ -73,10 +73,6 @@ struct
   newWindowButton = AUTORELEASE ([NSButton new]);
   [newWindowButton setTitle: @"Create Window"];
   [newWindowButton sizeToFit];
-  // Stand-alone buttons look better slighlty bigger
-  [newWindowButton setFrameSize: 
-		     NSMakeSize ([newWindowButton frame].size.width + 6, 
-				 [newWindowButton frame].size.height + 4)];
   [newWindowButton setAutoresizingMask: NSViewMinXMargin];
   [newWindowButton setTarget: self];
   [newWindowButton setAction: @selector (newWindow:)];
