@@ -262,9 +262,6 @@
   [window setContentView: scrollView];
   RELEASE(scrollView);
 
-  // Make the Document the delegate of the window
-  [window setDelegate: self];
-
   // Make the text view the first responder
   [window makeFirstResponder: textView];
   [window display];
